/*
 * thread.h
 *
 */

#include "jni.h"

//void java_lang_Thread_yield(JNIEnv* env, jobject obj);
/*void java_lang_Thread_sleep(JNIEnv* env, jobject obj, jlong millis, jint nanos);
void java_lang_Thread_start(JNIEnv* env, jobject obj);
void java_lang_Thread__throwState(JNIEnv* env, jobject obj, jobject throwobj, jint state, jlong millis, jint nanos);
void java_lang_Thread_destroy(JNIEnv* env, jobject obj);
jboolean java_lang_Thread_isAlive(JNIEnv* env, jobject obj);
void java_lang_Thread_suspend(JNIEnv* env, jobject obj);
void java_lang_Thread_resume(JNIEnv* env, jobject obj);
void java_lang_Thread_join(JNIEnv* env, jobject obj, jlong millis);
void java_lang_Thread__setPriority(JNIEnv* env, jobject obj, jint newPriority);
jint java_lang_Thread__countStackFrames(JNIEnv* env, jobject obj);

void java_lang_Thread__initC(JNIEnv* env, jobject obj);
void java_lang_Thread__link(JNIEnv* env, jobject obj);
void java_lang_Thread__createJNIData(JNIEnv* env, jobject obj);


*/
